summaryrefslogtreecommitdiffstats
path: root/src/corelib/tools/qlist.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/corelib/tools/qlist.cpp')
-rw-r--r--src/corelib/tools/qlist.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/corelib/tools/qlist.cpp b/src/corelib/tools/qlist.cpp
index 62201fd5d6..cdcfc30f28 100644
--- a/src/corelib/tools/qlist.cpp
+++ b/src/corelib/tools/qlist.cpp
@@ -50,8 +50,8 @@ QT_BEGIN_NAMESPACE
/*
### Qt 5:
### This needs to be removed for next releases of Qt. It is a workaround for vc++ because
### Qt exports QPolygon and QPolygonF that inherit QVector<QPoint> and
### QVector<QPointF> respectively.
*/
#if defined(Q_CC_MSVC) && defined(QT_BUILD_CORE_LIB)
@@ -59,8 +59,8 @@ QT_BEGIN_INCLUDE_NAMESPACE
#include <QtCore/qpoint.h>
QT_END_INCLUDE_NAMESPACE
-template class Q_CORE_EXPORT QVector<QPointF>;
-template class Q_CORE_EXPORT QVector<QPoint>;
+template class Q_CORE_EXPORT QList<QPointF>;
+template class Q_CORE_EXPORT QList<QPoint>;
#endif
QT_END_NAMESPACE
@@ -50,8 +50,8 @@ QT_BEGIN_NAMESPACE
### Qt 5:
### This needs to be removed for next releases of Qt. It is a workaround for vc++ because
- ### Qt exports QPolygon and QPolygonF that inherit QVector<QPoint> and
- ### QVector<QPointF> respectively.
+ ### Qt exports QPolygon and QPolygonF that inherit QList<QPoint> and
+ ### QList<QPointF> respectively.
*/
#if defined(Q_CC_MSVC) && defined(QT_BUILD_CORE_LIB)